%%%
%%% quarterly.cls - A class for quarterly journal articles
%%% by Ruediger Ehlers
%%%
%%% For comments, etc., please write to:
%%% Ruediger.Ehlers(--at--)arcor.de
%%%
%%% This class file can be redistributed and/or modified under the terms
%%% of the LaTeX Project Public License Distributed from CTAN
%%% archives in directory macros/latex/base/lppl.txt; either
%%% version 1 of the License, or any later version.


%% This is basically the latex 'article' style (with several modifications)
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{quarterly}[2006/08/20 v1.0 Document class for quarterly journal articles]
\ProcessOptions\relax
\LoadClass[10pt]{article}

% Load required packages
\RequirePackage[paperwidth=157mm, paperheight=233mm,vmargin={2.3cm,2.8cm},inner=2.1cm,outer=2.35cm,headsep=9pt,footskip=12pt,twoside]{geometry}
\RequirePackage{mathptmx}
\RequirePackage[scaled=0.9]{helvet}
\RequirePackage{courier}
\RequirePackage{fancyhdr}
\RequirePackage{calc}
\RequirePackage{caption}
\RequirePackage{ifthen}

% Define thanksto command
\newcommand{\@thanksto}{\empty}
\newcommand{\thanksto}[1]{\renewcommand{\@thanksto}{#1}}

% Define jel command
% (for economical papers)
\newcommand{\@jel}{\empty}
\newcommand{\jel}[1]{\renewcommand{\@jel}{#1}}

% Define keywords command
\newcommand{\@keywords}{\empty}
\newcommand{\keywords}[1]{\renewcommand{\@keywords}{#1}}

% Define journalissuetop command
\newcommand{\@journalissuetop}{\empty}
\newcommand{\journalissuetop}[1]{\renewcommand{\@journalissuetop}{#1}}

% Define journalissuebottom command
\newcommand{\@journalissuebottom}{\empty}
\newcommand{\journalissuebottom}[1]{\renewcommand{\@journalissuebottom}{#1}}

% Define publisher command
\newcommand{\@publisher}{\empty}
\newcommand{\publisher}[1]{\renewcommand{\@publisher}{#1}}

% Define shorttitle command
\newcommand{\@shorttitle}{\empty}
\newcommand{\shorttitle}[1]{\renewcommand{\@shorttitle}{#1}}

% Define shortauthor command
\newcommand{\@shortauthor}{\empty}
\newcommand{\shortauthor}[1]{\renewcommand{\@shortauthor}{#1}}

% Set caption style of floating objects
\DeclareCaptionLabelSeparator{double-newline}{\\ \vspace{3mm} }
\captionsetup{labelsep=double-newline,labelfont={small,it},textfont={small,bf},justification=centering}

% Change section heading style
\renewcommand\thesection      {\@arabic\c@section.}
\renewcommand\thesubsection   {\thesection\@arabic\c@subsection}
\renewcommand\thesubsubsection{\thesubsection.\@arabic\c@subsubsection}
\renewcommand\theparagraph    {\thesubsubsection.\@arabic\c@paragraph}
\renewcommand\thesubparagraph {\theparagraph.\@arabic\c@subparagraph}

\renewcommand\section{\@startsection{section}{1}{\z@}%
                                     {-4.0ex \@plus -1ex \@minus -.2ex}{1ex \@plus .2ex}
                                                 {\normalfont\normalsize\bfseries\centering}}
\renewcommand\subsection{\@startsection{subsection}{2}{\z@}%
                                     {-4.0ex \@plus -1ex \@minus -.2ex}{1ex \@plus .2ex}
                                     {\normalfont\small\bfseries\centering}}
\renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
                                     {-4.0ex \@plus -1ex \@minus -.2ex}{1ex \@plus .2ex}
                                     {\normalfont\small\bfseries\centering}}
\renewcommand\paragraph{\@startsection{paragraph}{4}{\z@}%
                                     {-0.1ex}{-1em}
                                     {\normalfont\small\bfseries}}
\renewcommand\subparagraph{\@startsection{subparagraph}{5}{\parindent}%
                                     {-0.1ex}{-1em}
                                     {\normalfont\small\bfseries}}

% Redefine the section counter format in order to avoid the \quad after the counter
\def\@seccntformat#1{\csname the#1\endcsname\ }

% Set paragraph style
\setlength{\parindent}{10pt}
\setlength{\parskip}{\baselineskip / 2}
\let\@afterindentfalse\@afterindenttrue
\@afterindenttrue

% Set page options
\renewcommand{\headrulewidth}{0pt}
\pagestyle{fancy}

% A special command to remove footnotes in texts
\newcommand{\removefootnotes}[1]{%
  \begingroup%
  \renewcommand\footnote[1]{}%
  #1%
  \endgroup%
}

% Set page options for the first page
\fancypagestyle{plain}{%
    \fancyhf{} % clear all header and footer fields
    \lhead{\setlength{\unitlength}{11pt}
    \begin{picture}(0.1,0.1)
    \put(0.0,0.0){\small \@journalissuetop \normalsize}
    \put(0.0,-1.0){\small \@publisher \normalsize}
    \end{picture}}
    \chead{}
    \rhead{}
    \lfoot{}
    \cfoot{}
    \lfoot{\tiny \@journalissuebottom}
    \renewcommand{\headrulewidth}{0pt}
    \renewcommand{\footrulewidth}{0pt}}


% Footnotes within the title and author names are written
% differently than in the standard class
\def\@fnsymbol#1{\ensuremath{\ifcase#1\or *\or ** \or  *** \or
   **** \or ***** \or ******
    \else\@ctrerr\fi}}

% Define how the title has to look like
\renewcommand\maketitle{\par

  % If no short title has been supplied, use the (long) title:
  \ifthenelse{\equal{\@shorttitle}{}}{\DeclareRobustCommand{\@titleforuseinpageheader}{\removefootnotes{\@title}}} %
             {\DeclareRobustCommand{\@titleforuseinpageheader}{\@shorttitle}}

  % If no short author list has been supplied, use the (long) list:
  \ifthenelse{\equal{\@shortauthor}{}}{\DeclareRobustCommand{\@authorforuseinpageheader}{\removefootnotes{\@author}}} %
             {\DeclareRobustCommand{\@authorforuseinpageheader}{\@shortauthor}}

  % Make the title
  \begingroup
    \renewcommand\thefootnote{\@fnsymbol\c@footnote}%
    \def\@makefnmark{%
       \@textsuperscript{\normalfont\@thefnmark}$\!\!$
      }%
    \long\def\@makefntext##1{\parindent 1em\noindent
            \hb@xt@1.8em{%
                \hss\@textsuperscript{\normalfont\@thefnmark}}##1}%
    \if@twocolumn
      \ifnum \col@number=\@ne
        \@maketitle
      \else
        \twocolumn[\@maketitle]%
      \fi
    \else
      \newpage
      \global\@topnum\z@
      \@maketitle
    \fi
    \thispagestyle{plain}
  \endgroup
  \setcounter{footnote}{0}%
  % Do not drop the \thanks command totally since this would cause errors when repeating
  % the author's name in page headers if \thanks is used.
  \renewcommand{\thanks}[1]{}%
  \global\let\maketitle\relax
  \global\let\@maketitle\relax
  \global\let\@thanks\@empty
  \global\let\@date\@empty
  \global\let\title\relax
  \global\let\author\relax
  \global\let\date\relax
  \global\let\and\relax
}

\def\@maketitle{%
  \newpage
  \null
  \vskip 3em%
  \begin{center}%
  \let \footnote \thanks
    {\large \textbf{\@title} \par}%
    \vskip 1.0em%
    {
      \lineskip .5em%
      \begin{tabular}[t]{c}%
        By \@author
      \end{tabular}\\}%
      % Inserting thanks here to have the footnotes it in the correct order.
      \@thanks%
      % From now on reduce the baselinestretch
      \renewcommand{\baselinestretch}{0.953} % Appears again in the abstract command
    \vskip-\parskip%
    \vskip-\parskip%
    %{\large \@date}%
  \end{center}%
  \vskip 1.5em

  \fancyhead{} % clear all header fields
  \fancyhead[CE]{\small \@authorforuseinpageheader}
  \fancyfoot{} % clear all footer fields
  \fancyhead[LE,RO]{\small \thepage}
  \fancyhead[CO]{\small \@titleforuseinpageheader}
  \fancyfoot[LO,RE]{\tiny \@journalissuebottom}

  % Insert "thanksto" into footnotes.
  % \@footnotetext{\@thanksto}
  \ifthenelse{\equal{\@thanksto}{}}{}{%
   \insert\footins{
    \reset@font\footnotesize
    \interlinepenalty\interfootnotelinepenalty
    \splittopskip\footnotesep
    \splitmaxdepth \dp\strutbox \floatingpenalty \@MM
    \hsize\columnwidth \@parboxrestore
    \protected@edef\@currentlabel{%
       \csname p@footnote\endcsname%\@thefnmark
    }%
    \color@begingroup
    \parindent 1em\noindent
            \hb@xt@1.8em{%
                \hss\@textsuperscript{\normalfont}}%
        \rule\z@\footnotesep\ignorespaces \@thanksto \@finalstrut\strutbox%
    \color@endgroup}%
   }%
}

% Change the way the abstract looks like
\renewenvironment{abstract}{%
        \if@twocolumn
        \section*{\abstractname}%
      \else
        \small%
        \begin{center}%
          {\bfseries \abstractname%
          \vspace{-.5em}
          \vspace{\z@}}%
        \end{center}%
        \par\hspace{\z@}%
      \fi%
        }%
      {\vspace{3mm}
      \small
      \ifthenelse{\equal{\@jel}{}}{}{\\ \textit{JEL Classification: \@jel}}
      \ifthenelse{\equal{\@keywords}{}}{}{\\ \textit{Keywords: \@keywords}}
      \setlength{\parskip}{\baselineskip / 2}
      \normalsize%
      }
